# KeyAtome PyPi
![GitHub release](https://img.shields.io/github/release/jugla/pyKeyAtome)

Get your energy consumption data from Atome, a Linky-compatible device made by Total/Direct-Energie.

### Installing

```
pip install pykeyatome
```


## Running the tests
The tox configuration is already included.
Simply launch:
```
$ tox
```

(Do not forget to 'pip install tox' if you do not have it.)
Tests are written in the tests directory.
tests/data folder contains samples of Atome API for tests purposes.


## Side notes

This project is based on reverse engineering of Atome IOS APP performed by BaQs.


## Contributing

Any contribution is welcome, considering the number of features the API provides, there is room for improvement!

## Acknowledgments

* Thanks to k20human for the original inspiration with https://github.com/k20human/domoticz-atome
* This project is a fork of https://github.com/BaQs/pyAtome (seems to be unmaintained)

## Changelog

### 1.0.0 first release
